@@ -1,6 +1,7 @@
 
 import sys
 import site
+import gc
 
 
 def main():
@@ -21,6 +22,9 @@ def main():
             sys.modules.pop(module)
 
         del dummy_autoupdate
+
+        gc.collect()
+
         import dummy_autoupdate
 
         reboot_code = dummy_autoupdate.MainWindow.EXIT_CODE_REBOOT
